.. image::
   https://raw.githubusercontent.com/we3lab/pype-schema/refs/heads/main/docs/_static/pypes-logo.png

*********************************************
Python for Process Engineering Schema (PyPES)
*********************************************

.. image::
   https://github.com/we3lab/pype-schema/workflows/Build%20Main/badge.svg
   :height: 30
   :target: https://github.com/we3lab/pype-schema/actions
   :alt: Build Status

.. image::
   https://github.com/we3lab/pype-schema/workflows/Documentation/badge.svg
   :height: 30
   :target: https://we3lab.github.io/pype-schema
   :alt: Documentation

.. image::
   https://codecov.io/gh/we3lab/pype-schema/branch/main/graph/badge.svg
   :height: 30
   :target: https://codecov.io/gh/we3lab/pype-schema
   :alt: Code Coverage

.. image:: https://zenodo.org/badge/511340686.svg
  :height: 30
  :target: https://doi.org/10.5281/zenodo.17042020
  :alt: Zenodo DOI

A class hierarchy designed to represent configurations of process engineering systems, such as wastewater treatment or desalination plants.

Full documentation available at https://we3lab.github.io/pype-schema/.

Useful Commands
===============

1. ``pip install -e .``

  This will install your package in editable mode.

2. ``pytest pype_schema/tests --cov=pype_schema --cov-report=html``

  Produces an HTML test coverage report for the entire project which can
  be found at ``htmlcov/index.html``.

3. ``docs/make html``

  This will generate an HTML version of the documentation which can be found
  at ``_build/html/index.html``.

4. ``flake8 pype_schema --count --verbose --show-source --statistics``

  This will lint the code and share all the style errors it finds.

5. ``black pype_schema``

  This will reformat the code according to strict style guidelines.

Legal Documents
===============

This work is supported by the National Alliance for Water Innovation (NAWI), funded by the U.S. Department of Energy, Energy Efficiency and Renewable Energy Office, Advanced Manufacturing Office under Funding Opportunity Announcement DE-FOA-0001905. The views expressed herein do not necessarily represent the views of the U.S. Department of Energy or the United States Government.

This work is also supported by the `Center for Integrated Facility Engineering <https://cife.stanford.edu/>`_ at Stanford University as a
a part of CIFE Seed Proposal 2023-02
`Formal proofs of safe operating limits at wastewater resource recovery facilities <https://cife.stanford.edu/formal-proofs-safe-operating-limits-wastewater-resource-recovery-facilities>`_.

- `LICENSE <https://github.com/we3lab/pype-schema/blob/main/LICENSE/>`_
- `CONTRIBUTING <https://github.com/we3lab/pype-schema/blob/main/CONTRIBUTING.rst/>`_
